@@ -5,7 +5,7 @@ use warnings;
 use parent qw( Alien::Base );
 use Capture::Tiny qw /:all/;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub patchelf {
     my ($self, @args) = @_;
@@ -30,6 +30,9 @@ Alien::patchelf - Alien module for the patchelf utility
 =head1 SYNOPSIS
 
     use Alien::patchelf;
+    
+    my ($stdout, $stderr, @errors)
+      = 'Alien::patchelf'->patchelf('--print-rpath', '/path/to/some/library.so');
 
     
 =head1 DESCRIPTION
@@ -40,17 +43,17 @@ The patchelf utility is used for this purpose.
 
 This is not useful on Windows since dynamic libs are loaded from the PATH.
 
-As with mosst aliens, if your system provides the patchelf utility
+As with most aliens, if your system provides the patchelf utility
 then that will be used.  If not then it will be downloaded and installed for you.  
 
 =head1 METHODS
 
-This moule inherits from Alien:::Base so all of those methods are available.
+This module inherits from Alien:::Base so all of those methods are available.
 
 =head2 patchelf
 
 Runs the patchelf command, passing any arguments through.
-Uses a L<system> call via L<Capture::Tiny>, and it is up to the caller to handle the results.  
+Uses a C<system> call via L<Capture::Tiny>, and it is up to the caller to handle the results.  
 
 
 =head1 REPORTING BUGS
